# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.73
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json




from pydantic import BaseModel, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from nuon.models.app_app_runner_config import AppAppRunnerConfig
from nuon.models.app_app_sandbox_config import AppAppSandboxConfig
from nuon.models.app_aws_account import AppAWSAccount
from nuon.models.app_install_component import AppInstallComponent
from nuon.models.app_install_inputs import AppInstallInputs
from nuon.models.app_install_sandbox_run import AppInstallSandboxRun
from nuon.models.app_user_token import AppUserToken
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class AppInstall(BaseModel):
    """
    AppInstall
    """ # noqa: E501
    app_id: Optional[StrictStr] = None
    app_runner_config: Optional[AppAppRunnerConfig] = None
    app_sandbox_config: Optional[AppAppSandboxConfig] = None
    aws_account: Optional[AppAWSAccount] = None
    created_at: Optional[StrictStr] = None
    created_by: Optional[AppUserToken] = None
    created_by_id: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    install_components: Optional[List[AppInstallComponent]] = None
    install_inputs: Optional[List[AppInstallInputs]] = None
    install_sandbox_runs: Optional[List[AppInstallSandboxRun]] = None
    name: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    status_description: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["app_id", "app_runner_config", "app_sandbox_config", "aws_account", "created_at", "created_by", "created_by_id", "id", "install_components", "install_inputs", "install_sandbox_runs", "name", "status", "status_description", "updated_at"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AppInstall from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of app_runner_config
        if self.app_runner_config:
            _dict['app_runner_config'] = self.app_runner_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of app_sandbox_config
        if self.app_sandbox_config:
            _dict['app_sandbox_config'] = self.app_sandbox_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of aws_account
        if self.aws_account:
            _dict['aws_account'] = self.aws_account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['created_by'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in install_components (list)
        _items = []
        if self.install_components:
            for _item in self.install_components:
                if _item:
                    _items.append(_item.to_dict())
            _dict['install_components'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in install_inputs (list)
        _items = []
        if self.install_inputs:
            for _item in self.install_inputs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['install_inputs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in install_sandbox_runs (list)
        _items = []
        if self.install_sandbox_runs:
            for _item in self.install_sandbox_runs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['install_sandbox_runs'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of AppInstall from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "app_id": obj.get("app_id"),
            "app_runner_config": AppAppRunnerConfig.from_dict(obj.get("app_runner_config")) if obj.get("app_runner_config") is not None else None,
            "app_sandbox_config": AppAppSandboxConfig.from_dict(obj.get("app_sandbox_config")) if obj.get("app_sandbox_config") is not None else None,
            "aws_account": AppAWSAccount.from_dict(obj.get("aws_account")) if obj.get("aws_account") is not None else None,
            "created_at": obj.get("created_at"),
            "created_by": AppUserToken.from_dict(obj.get("created_by")) if obj.get("created_by") is not None else None,
            "created_by_id": obj.get("created_by_id"),
            "id": obj.get("id"),
            "install_components": [AppInstallComponent.from_dict(_item) for _item in obj.get("install_components")] if obj.get("install_components") is not None else None,
            "install_inputs": [AppInstallInputs.from_dict(_item) for _item in obj.get("install_inputs")] if obj.get("install_inputs") is not None else None,
            "install_sandbox_runs": [AppInstallSandboxRun.from_dict(_item) for _item in obj.get("install_sandbox_runs")] if obj.get("install_sandbox_runs") is not None else None,
            "name": obj.get("name"),
            "status": obj.get("status"),
            "status_description": obj.get("status_description"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_app_runner_config import AppAppRunnerConfig

class TestAppAppRunnerConfig(unittest.TestCase):
    """AppAppRunnerConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAppRunnerConfig:
        """Test AppAppRunnerConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAppRunnerConfig`
        """
        model = AppAppRunnerConfig()
        if include_optional:
            return AppAppRunnerConfig(
                app_id = '',
                app_runner_type = 'aws-ecs',
                created_at = '',
                created_by_id = '',
                env_vars = {
                    'key' : ''
                    },
                id = '',
                org_id = '',
                updated_at = ''
            )
        else:
            return AppAppRunnerConfig(
        )
        """

    def testAppAppRunnerConfig(self):
        """Test AppAppRunnerConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.73
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.19.73"

# import apis into sdk package
from nuon.api.apps_api import AppsApi
from nuon.api.components_api import ComponentsApi
from nuon.api.general_api import GeneralApi
from nuon.api.installers_api import InstallersApi
from nuon.api.installs_api import InstallsApi
from nuon.api.orgs_api import OrgsApi
from nuon.api.releases_api import ReleasesApi
from nuon.api.sandboxes_api import SandboxesApi
from nuon.api.vcs_api import VcsApi

# import ApiClient
from nuon.api_response import ApiResponse
from nuon.api_client import ApiClient
from nuon.configuration import Configuration
from nuon.exceptions import OpenApiException
from nuon.exceptions import ApiTypeError
from nuon.exceptions import ApiValueError
from nuon.exceptions import ApiKeyError
from nuon.exceptions import ApiAttributeError
from nuon.exceptions import ApiException

# import models into sdk package
from nuon.models.app_aws_account import AppAWSAccount
from nuon.models.app_awsecr_image_config import AppAWSECRImageConfig
from nuon.models.app_app import AppApp
from nuon.models.app_app_input import AppAppInput
from nuon.models.app_app_input_config import AppAppInputConfig
from nuon.models.app_app_installer import AppAppInstaller
from nuon.models.app_app_installer_metadata import AppAppInstallerMetadata
from nuon.models.app_app_runner_config import AppAppRunnerConfig
from nuon.models.app_app_runner_type import AppAppRunnerType
from nuon.models.app_app_sandbox_config import AppAppSandboxConfig
from nuon.models.app_app_sandbox_config_artifacts import AppAppSandboxConfigArtifacts
from nuon.models.app_component import AppComponent
from nuon.models.app_component_build import AppComponentBuild
from nuon.models.app_component_config_connection import AppComponentConfigConnection
from nuon.models.app_component_release import AppComponentRelease
from nuon.models.app_component_release_step import AppComponentReleaseStep
from nuon.models.app_connected_github_vcs_config import AppConnectedGithubVCSConfig
from nuon.models.app_docker_build_component_config import AppDockerBuildComponentConfig
from nuon.models.app_external_image_component_config import AppExternalImageComponentConfig
from nuon.models.app_helm_component_config import AppHelmComponentConfig
from nuon.models.app_install import AppInstall
from nuon.models.app_install_component import AppInstallComponent
from nuon.models.app_install_deploy import AppInstallDeploy
from nuon.models.app_install_deploy_type import AppInstallDeployType
from nuon.models.app_install_inputs import AppInstallInputs
from nuon.models.app_install_sandbox_run import AppInstallSandboxRun
from nuon.models.app_job_component_config import AppJobComponentConfig
from nuon.models.app_org import AppOrg
from nuon.models.app_org_health_check import AppOrgHealthCheck
from nuon.models.app_org_health_check_status import AppOrgHealthCheckStatus
from nuon.models.app_public_git_vcs_config import AppPublicGitVCSConfig
from nuon.models.app_sandbox import AppSandbox
from nuon.models.app_sandbox_release import AppSandboxRelease
from nuon.models.app_sandbox_run_type import AppSandboxRunType
from nuon.models.app_terraform_module_component_config import AppTerraformModuleComponentConfig
from nuon.models.app_token_type import AppTokenType
from nuon.models.app_user_org import AppUserOrg
from nuon.models.app_user_token import AppUserToken
from nuon.models.app_vcs_connection import AppVCSConnection
from nuon.models.app_vcs_connection_commit import AppVCSConnectionCommit
from nuon.models.metrics_decr import MetricsDecr
from nuon.models.metrics_event import MetricsEvent
from nuon.models.metrics_incr import MetricsIncr
from nuon.models.metrics_timing import MetricsTiming
from nuon.models.planv1_plan import Planv1Plan
from nuon.models.service_app_input_request import ServiceAppInputRequest
from nuon.models.service_aws_ecr_image_config_request import ServiceAwsECRImageConfigRequest
from nuon.models.service_cli_config import ServiceCLIConfig
from nuon.models.service_connected_github_vcs_config_request import ServiceConnectedGithubVCSConfigRequest
from nuon.models.service_connected_github_vcs_sandbox_config_request import ServiceConnectedGithubVCSSandboxConfigRequest
from nuon.models.service_create_app_input_config_request import ServiceCreateAppInputConfigRequest
from nuon.models.service_create_app_installer_request import ServiceCreateAppInstallerRequest
from nuon.models.service_create_app_installer_request_links import ServiceCreateAppInstallerRequestLinks
from nuon.models.service_create_app_request import ServiceCreateAppRequest
from nuon.models.service_create_app_runner_config_request import ServiceCreateAppRunnerConfigRequest
from nuon.models.service_create_app_sandbox_config_request import ServiceCreateAppSandboxConfigRequest
from nuon.models.service_create_component_build_request import ServiceCreateComponentBuildRequest
from nuon.models.service_create_component_release_request import ServiceCreateComponentReleaseRequest
from nuon.models.service_create_component_release_request_strategy import ServiceCreateComponentReleaseRequestStrategy
from nuon.models.service_create_component_request import ServiceCreateComponentRequest
from nuon.models.service_create_connection_callback_request import ServiceCreateConnectionCallbackRequest
from nuon.models.service_create_connection_request import ServiceCreateConnectionRequest
from nuon.models.service_create_docker_build_component_config_request import ServiceCreateDockerBuildComponentConfigRequest
from nuon.models.service_create_external_image_component_config_request import ServiceCreateExternalImageComponentConfigRequest
from nuon.models.service_create_helm_component_config_request import ServiceCreateHelmComponentConfigRequest
from nuon.models.service_create_install_deploy_request import ServiceCreateInstallDeployRequest
from nuon.models.service_create_install_inputs_request import ServiceCreateInstallInputsRequest
from nuon.models.service_create_install_request import ServiceCreateInstallRequest
from nuon.models.service_create_install_request_aws_account import ServiceCreateInstallRequestAwsAccount
from nuon.models.service_create_job_component_config_request import ServiceCreateJobComponentConfigRequest
from nuon.models.service_create_org_request import ServiceCreateOrgRequest
from nuon.models.service_create_org_user_request import ServiceCreateOrgUserRequest
from nuon.models.service_create_terraform_module_component_config_request import ServiceCreateTerraformModuleComponentConfigRequest
from nuon.models.service_public_git_vcs_config_request import ServicePublicGitVCSConfigRequest
from nuon.models.service_public_git_vcs_sandbox_config_request import ServicePublicGitVCSSandboxConfigRequest
from nuon.models.service_publish_metric_input import ServicePublishMetricInput
from nuon.models.service_rendered_install import ServiceRenderedInstall
from nuon.models.service_rendered_installer import ServiceRenderedInstaller
from nuon.models.service_repository import ServiceRepository
from nuon.models.service_update_app_request import ServiceUpdateAppRequest
from nuon.models.service_update_component_request import ServiceUpdateComponentRequest
from nuon.models.service_update_install_request import ServiceUpdateInstallRequest
from nuon.models.service_update_installer_request import ServiceUpdateInstallerRequest
from nuon.models.service_update_installer_request_links import ServiceUpdateInstallerRequestLinks
from nuon.models.service_update_org_request import ServiceUpdateOrgRequest
from nuon.models.statsd_event import StatsdEvent
from nuon.models.statsd_event_alert_type import StatsdEventAlertType
from nuon.models.statsd_event_priority import StatsdEventPriority
from nuon.models.stderr_err_response import StderrErrResponse
